@@ -4,13 +4,6 @@
  * No warranty is given; refer to the file DISCLAIMER.PD within this package.
  */
 
-#undef CRTDLL
-#ifndef _DLL
-#define _DLL
-#endif
-
-#define SPECIAL_CRTEXE
-
 #include <oscalls.h>
 #include <internal.h>
 #include <process.h>
@@ -20,34 +13,23 @@
 #include <tchar.h>
 #include <sect_attribs.h>
 #include <locale.h>
+#include <float.h>
+#include <corecrt_startup.h>
 
 #if defined(__SEH__) && (!defined(__clang__) || __clang_major__ >= 7)
 #define SEH_INLINE_ASM
 #endif
 
-#ifndef __winitenv
-extern wchar_t *** __MINGW_IMP_SYMBOL(__winitenv);
-#define __winitenv (* __MINGW_IMP_SYMBOL(__winitenv))
-#endif
-
-#if !defined(__initenv)
-extern char *** __MINGW_IMP_SYMBOL(__initenv);
-#define __initenv (* __MINGW_IMP_SYMBOL(__initenv))
-#endif
-
 extern IMAGE_DOS_HEADER __ImageBase;
 
-extern void _fpreset (void);
-
 int *__cdecl __p__commode(void);
 
 #undef _fmode
 extern int _fmode;
+#undef _commode
 extern int _commode;
 extern int _dowildcard;
 
-extern _CRTIMP void __cdecl _initterm(_PVFV *, _PVFV *);
-
 static int __cdecl check_managed_app (void);
 
 extern _PIFV __xi_a[];
@@ -66,21 +48,13 @@ extern void __main(void);
 static _TCHAR **argv;
 static _TCHAR **envp;
 
-static int argret;
-static int mainret=0;
 static int managedapp;
 static int has_cctor = 0;
-static _startupinfo startinfo;
 extern LPTOP_LEVEL_EXCEPTION_FILTER __mingw_oldexcpt_handler;
 
 extern void _pei386_runtime_relocator (void);
 long CALLBACK _gnu_exception_handler (EXCEPTION_POINTERS * exception_data);
-static void duplicate_ppstrings (int ac, _TCHAR ***av);
-
-static int __cdecl pre_c_init (void);
-static void __cdecl pre_cpp_init (void);
-_CRTALLOC(".CRT$XIAA") _PIFV __mingw_pcinit = pre_c_init;
-_CRTALLOC(".CRT$XCAA") _PVFV __mingw_pcppinit = pre_cpp_init;
+static int duplicate_ppstrings (int ac, _TCHAR ***av);
 
 extern int _MINGW_INSTALL_DEBUG_MATHERR;
 
@@ -102,46 +76,6 @@ __mingw_invalidParameterHandler (const wchar_t * __UNUSED_PARAM_1(expression),
 #endif
 }
 
-static int __cdecl
-pre_c_init (void)
-{
-  managedapp = check_managed_app ();
-  if (__mingw_app_type)
-    __set_app_type(_GUI_APP);
-  else
-    __set_app_type (_CONSOLE_APP);
-
-  * __p__fmode() = _fmode;
-  * __p__commode() = _commode;
-
-#ifdef _UNICODE
-  _wsetargv();
-#else
-  _setargv();
-#endif
-  if (_MINGW_INSTALL_DEBUG_MATHERR == 1)
-    {
-      __setusermatherr (_matherr);
-    }
-
-  if (__globallocalestatus == -1)
-    {
-    }
-  return 0;
-}
-
-static void __cdecl
-pre_cpp_init (void)
-{
-  startinfo.newmode = _newmode;
-
-#ifdef _UNICODE
-  argret = __wgetmainargs(&argc,&argv,&envp,_dowildcard,&startinfo);
-#else
-  argret = __getmainargs(&argc,&argv,&envp,_dowildcard,&startinfo);
-#endif
-}
-
 static int __tmainCRTStartup (void);
 
 int WinMainCRTStartup (void);
@@ -205,7 +139,7 @@ int mainCRTStartup (void)
 static
 #if defined(__i386__) || defined(_X86_)
 /* We need to make sure that we align the stack to 16 bytes for the sake of SSE
-   opts in main or in functions called main.  */
+   opts in main or in functions called from main.  */
 __attribute__((force_align_arg_pointer))
 #endif
 __declspec(noinline) int
@@ -213,9 +147,11 @@ __tmainCRTStartup (void)
 {
     void *lock_free = NULL;
     void *fiberid = ((PNT_TIB)NtCurrentTeb())->StackBase;
-    int nested = FALSE;
-    while((lock_free = InterlockedCompareExchangePointer ((volatile PVOID *) &__native_startup_lock,
-							  fiberid, 0)) != 0)
+    BOOL nested = FALSE;
+    _startupinfo startinfo;
+    int ret = 0;
+    while((lock_free = InterlockedCompareExchangePointer (&__native_startup_lock,
+							  fiberid, NULL)) != 0)
       {
 	if (lock_free == fiberid)
 	  {
@@ -231,47 +167,80 @@ __tmainCRTStartup (void)
     else if (__native_startup_state == __uninitialized)
       {
 	__native_startup_state = __initializing;
-	_initterm ((_PVFV *)(void *)__xi_a, (_PVFV *)(void *) __xi_z);
+
+	_pei386_runtime_relocator ();
+#if defined(__x86_64__) && !defined(__SEH__)
+	__mingw_init_ehandler ();
+#endif
+	__mingw_oldexcpt_handler = SetUnhandledExceptionFilter (_gnu_exception_handler);
+	_set_invalid_parameter_handler (__mingw_invalidParameterHandler);
+	_fpreset ();
+
+	managedapp = check_managed_app ();
+	if (__mingw_app_type)
+	  __set_app_type (_GUI_APP);
+	else
+	  __set_app_type (_CONSOLE_APP);
+
+	*__p__fmode () = _fmode;
+	*__p__commode () = _commode;
+
+#ifdef _UNICODE
+	ret = _wsetargv ();
+#else
+	ret = _setargv ();
+#endif
+	if (ret < 0)
+	  _amsg_exit (8); /* _RT_SPACEARG */
+
+	if (_MINGW_INSTALL_DEBUG_MATHERR == 1)
+	  __setusermatherr (_matherr);
+
+	if (__globallocalestatus == -1)
+	  _configthreadlocale (-1);
+
+	if (_initterm_e (__xi_a, __xi_z) != 0)
+	  return 255;
+
+	startinfo.newmode = _newmode;
+#ifdef _UNICODE
+	ret = __wgetmainargs (&argc, &argv, &envp, _dowildcard, &startinfo);
+#else
+	ret = __getmainargs (&argc, &argv, &envp, _dowildcard, &startinfo);
+#endif
+	if (ret < 0)
+	  _amsg_exit (8); /* _RT_SPACEARG */
+
+	ret = duplicate_ppstrings (argc, &argv);
+	if (ret != 0)
+	  _amsg_exit (8); /* _RT_SPACEARG */
+
+	_initterm (__xc_a, __xc_z);
+	__main (); /* C++ initialization. */
+
+	__native_startup_state = __initialized;
       }
     else
       has_cctor = 1;
-
-    if (__native_startup_state == __initializing)
-      {
-	_initterm (__xc_a, __xc_z);
-	__native_startup_state = __initialized;
-      }
-    _ASSERTE(__native_startup_state == __initialized);
     if (! nested)
-      (VOID)InterlockedExchangePointer ((volatile PVOID *) &__native_startup_lock, 0);
+      (VOID)InterlockedExchangePointer (&__native_startup_lock, NULL);
     
     if (__dyn_tls_init_callback != NULL)
       __dyn_tls_init_callback (NULL, DLL_THREAD_ATTACH, NULL);
-    
-    _pei386_runtime_relocator ();
-    __mingw_oldexcpt_handler = SetUnhandledExceptionFilter (_gnu_exception_handler);
-#if defined(__x86_64__) && !defined(__SEH__)
-    __mingw_init_ehandler ();
-#endif
-    _set_invalid_parameter_handler (__mingw_invalidParameterHandler);
-    
-    _fpreset ();
 
-    duplicate_ppstrings (argc, &argv);
-    __main (); /* C++ initialization. */
 #ifdef _UNICODE
     __winitenv = envp;
 #else
     __initenv = envp;
 #endif
-    mainret = _tmain (argc, argv, envp);
+    ret = _tmain (argc, argv, envp);
     if (!managedapp)
-      exit (mainret);
+      exit (ret);
 
     if (has_cctor == 0)
       _cexit ();
 
-  return mainret;
+  return ret;
 }
 
 extern int __mingw_initltsdrot_force;
@@ -315,26 +284,34 @@ check_managed_app (void)
   return 0;
 }
 
-static void duplicate_ppstrings (int ac, _TCHAR ***av)
+static int duplicate_ppstrings (int ac, _TCHAR ***av)
 {
 	_TCHAR **avl;
 	int i;
 	_TCHAR **n = (_TCHAR **) malloc (sizeof (_TCHAR *) * (ac + 1));
+	if (!n) return 1;
 	
 	avl=*av;
 	for (i=0; i < ac; i++)
 	  {
 		size_t l = sizeof (_TCHAR) * (_tcslen (avl[i]) + 1);
 		n[i] = (_TCHAR *) malloc (l);
+		if (!n[i]) return 1;
 		memcpy (n[i], avl[i], l);
 	  }
 	n[i] = NULL;
 	*av = n;
+	return 0;
 }
 
 int __cdecl atexit (_PVFV func)
 {
-    return _onexit((_onexit_t)func) ? 0 : -1;
+    /*
+     * msvcrt def file renames the real atexit() function to _crt_atexit().
+     * UCRT provides atexit() function only under name _crt_atexit().
+     * So redirect call to _crt_atexit() function.
+     */
+    return _crt_atexit(func);
 }
 
 char __mingw_module_is_dll = 0;
