@@ -8,9 +8,5 @@
 
 long double log1pl(long double x)
 {
-#if defined(__arm__) || defined(_ARM_) || defined(__aarch64__) || defined(_ARM64_)
     return log1p(x);
-#else
-#error Not supported on your platform yet
-#endif
 }
