@@ -8,9 +8,5 @@
 
 long double powl(long double x, long double y)
 {
-#if defined(__arm__) || defined(_ARM_) || defined(__aarch64__) || defined(_ARM64_)
     return pow(x, y);
-#else
-#error Not supported on your platform yet
-#endif
 }
