@@ -17,7 +17,6 @@ and sets C1 flag (signbit) if neg */
 
 int __fpclassify (double _x)
 {
-#ifdef __x86_64__
     __mingw_dbl_type_t hlp;
     unsigned int l, h;
 
@@ -32,13 +31,4 @@ int __fpclassify (double _x)
     if (h == 0x7ff00000)
       return (l ? FP_NAN : FP_INFINITE);
     return FP_NORMAL;
-#else
-  unsigned short sw;
-  __asm__ __volatile__ (
-	"fxam; fstsw %%ax;"
-	: "=a" (sw)
-	: "t" (_x)
-	);
-  return sw & (FP_NAN | FP_NORMAL | FP_ZERO);
-#endif
 }
