@@ -3,7 +3,7 @@
  * This file is part of the mingw-w64 runtime package.
  * No warranty is given; refer to the file DISCLAIMER.PD within this package.
  */
-#include <fenv.h> 
+#include <internal.h>
 
 /* 7.6.2.3
    The feraiseexcept function raises the supported exceptions
@@ -13,18 +13,16 @@
    the inexact exception whenever it raises the overflow
    or underflow exception is implementation-defined. */
 
-int feraiseexcept (int excepts)
+int feraiseexcept(int flags)
 {
-  fenv_t _env;
-#if defined(_ARM_) || defined(__arm__)
-  __asm__ volatile ("fmrx %0, FPSCR" : "=r" (_env));
-  _env.__cw |= excepts & FE_ALL_EXCEPT;
-  __asm__ volatile ("fmxr FPSCR, %0" : : "r" (_env));
-#else
-  __asm__ volatile ("fnstenv %0;" : "=m" (_env));
-  _env.__status_word |= excepts & FE_ALL_EXCEPT;
-  __asm__ volatile ("fldenv %0;"
-		    "fwait;" : : "m" (_env));
-#endif /* defined(_ARM_) || defined(__arm__) */
-  return 0;
+    fenv_t env;
+
+    flags &= FE_ALL_EXCEPT;
+    fegetenv(&env);
+    env._Fe_stat |= fenv_encode(flags, flags);
+    fesetenv(&env);
+#if defined(__i386__) || (defined(__x86_64__) && !defined(__arm64ec__))
+    __asm__ volatile ("fwait\n\t");
+#endif
+    return 0;
 }
