@@ -4,9 +4,6 @@
 #include <errno.h>
 #include <msvcrt.h>
 
-errno_t __cdecl _localtime64_s (struct tm *, const __time64_t *);
-errno_t __cdecl asctime_s (char *, size_t, const struct tm *);
-errno_t __cdecl _ctime64_s (char *, size_t, const __time64_t *);
 static errno_t __cdecl _int_ctime64_s (char *, size_t, const __time64_t *);
 static errno_t __cdecl _stub (char *, size_t, const __time64_t *);
 
@@ -20,7 +17,7 @@ _stub (char *d, size_t dn, const __time64_t *pt)
 
   if (f == _stub)
     {
-	f = (errno_t __cdecl (*)(char *, size_t, const __time64_t *))
+	f = (void*)
 	    GetProcAddress (__mingw_get_msvcrt_handle (), "_ctime64_s");
 	if (!f)
 	  f = _int_ctime64_s;
