@@ -4,8 +4,6 @@
 #include <errno.h>
 #include <msvcrt.h>
 
-/* struct tm * __cdecl _gmtime32 (const __time32_t *); */
-errno_t __cdecl _gmtime32_s (struct tm *, const __time32_t *);
 static errno_t __cdecl _int_gmtime32_s (struct tm *, const __time32_t *);
 static errno_t __cdecl _stub (struct tm *, const __time32_t *);
 
@@ -19,7 +17,7 @@ _stub (struct tm *ptm, const __time32_t *pt)
 
   if (f == _stub)
     {
-	f = (errno_t __cdecl (*)(struct tm *, const __time32_t *))
+	f = (void*)
 	    GetProcAddress (__mingw_get_msvcrt_handle (), "_gmtime32_s");
 	if (!f)
 	  f = _int_gmtime32_s;
