@@ -1,9 +1,9 @@
 #include <windows.h>
 #include <malloc.h>
+#include <time.h>
 #include <errno.h>
 #include <msvcrt.h>
 
-errno_t __cdecl _strtime_s (char *, size_t);
 static errno_t __cdecl _int_strtime_s (char *, size_t);
 static errno_t __cdecl _stub (char *, size_t);
 
@@ -17,7 +17,7 @@ _stub (char *d, size_t dn)
 
   if (f == _stub)
     {
-	f = (errno_t __cdecl (*)(char *, size_t))
+	f = (void*)
 	    GetProcAddress (__mingw_get_msvcrt_handle (), "_strtime_s");
 	if (!f)
 	  f = _int_strtime_s;
