@@ -3,7 +3,6 @@
 #include <errno.h>
 #include <msvcrt.h>
 
-errno_t __cdecl memcpy_s (void *, size_t, const void *, size_t);
 static errno_t __cdecl _int_memcpy_s (void *, size_t, const void *, size_t);
 static errno_t __cdecl _stub (void *, size_t, const void *, size_t);
 
@@ -17,7 +16,7 @@ _stub (void *d, size_t dn, const void *s, size_t n)
 
   if (f == _stub)
     {
-	f = (errno_t __cdecl (*)(void *, size_t, const void *, size_t))
+	f = (void*)
 	    GetProcAddress (__mingw_get_msvcrt_handle (), "memcpy_s");
 	if (!f)
 	  f = _int_memcpy_s;
