@@ -1,4 +1,3 @@
-#define MINGW_HAS_SECURE_API 1
 #include <windows.h>
 #include <malloc.h>
 #include <errno.h>
@@ -19,7 +18,7 @@ _stub (char *_DstBuf, size_t _Size, const char *_Format, va_list _ArgList)
 
   if (f == _stub)
     {
-	f = (int __cdecl (*)(char *, size_t, const char *, va_list))
+	f = (void*)
 	    GetProcAddress (__mingw_get_msvcrt_handle (), "vsprintf_s");
 	if (!f)
 	  f = _int_vsprintf_s;
