@@ -6,6 +6,9 @@
 #ifndef __ROUTING_IPRTRMIB_H__
 #define __ROUTING_IPRTRMIB_H__
 
+#include <winapifamily.h>
+#if WINAPI_FAMILY_PARTITION (WINAPI_PARTITION_DESKTOP)
+
 #include <mprapi.h>
 #include <ipmib.h>
 #include <ipifcons.h>
@@ -772,4 +775,6 @@ typedef enum _TCPIP_OWNER_MODULE_INFO_CLASS {
 
 #define CAST_MIB_INFO(X,Y,Z) Z = (Y)(X->rgbyData)
 
+#endif /*WINAPI_FAMILY_PARTITION (WINAPI_PARTITION_DESKTOP)*/
+
 #endif /* __ROUTING_IPRTRMIB_H__ */
