@@ -111,6 +111,7 @@ for f in \
 	exdispid.h \
 	fontsub.h \
 	mediaerr.h \
+	mpeg2bits.h \
 	mscat.h \
 	msxml2did.h \
 	msxml6did.h \
@@ -120,9 +121,12 @@ for f in \
 	uiautomationcoreapi.h \
 	uiautomation.h \
 	vfwmsgs.h \
+	webservices.h \
+	wia.h \
 	winhttp.h \
 	winineti.h \
 	wmpids.h \
+	x3daudio.h \
 	xapofx.h \
 	xinput.h; do
     import_header $f include
@@ -187,6 +191,7 @@ for f in \
 	evr9 \
 	exdisp \
 	fusion \
+	httprequest \
 	icftypes \
 	ivectorchangedeventargs \
 	mediaobj \
@@ -195,6 +200,8 @@ for f in \
 	mftransform \
 	mmdeviceapi \
 	mmstream \
+	mpeg2data \
+	mpeg2structs \
 	mscoree \
 	msctf \
 	msxml \
@@ -217,6 +224,9 @@ for f in \
 	uiautomationcore \
 	urlhist \
 	vmr9 \
+	weakreference \
+	wia_lh \
+	wia_xp \
 	wincodec \
 	wincodecsdk \
 	windowscontracts \
