@@ -20,12 +20,20 @@
    DEALINGS IN THE SOFTWARE.
 */
 
-#include <windows.h>
-#include <stdio.h>
-#include "pthread.h"
-#include "thread.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
+#include <stdio.h>
+
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+
+/* public header files */
+#include "pthread.h"
+/* internal header files */
 #include "misc.h"
+#include "thread.h"
 
 int sched_get_priority_min(int pol)
 {
@@ -89,18 +97,13 @@ int pthread_attr_getschedpolicy (const pthread_attr_t *attr, int *pol)
 static int pthread_check(pthread_t t)
 {
   struct _pthread_v *pv;
-  DWORD dwFlags;
+
   if (!t)
     return ESRCH;
   pv = __pth_gpointer_locked (t);
-  if (!(pv->h) || pv->h == INVALID_HANDLE_VALUE)
-  {
-  	if (pv->ended == 0)
-  	  return 0;
-        return ESRCH;
-  }
-  else if ((!GetHandleInformation(pv->h, &dwFlags) && pv->ended))
-        return ESRCH;
+  if (pv->ended == 0)
+    return 0;
+  CHECK_OBJECT(pv, ESRCH);
   return 0;
 }
 
