@@ -20,15 +20,23 @@
    DEALINGS IN THE SOFTWARE.
 */
 
-#include <windows.h>
-#include <stdio.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <malloc.h>
+#include <stdio.h>
+
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+
+/* public header files */
 #include "pthread.h"
-#include "thread.h"
-#include "misc.h"
 #include "semaphore.h"
+/* internal header files */
+#include "misc.h"
 #include "sem.h"
-#include "ref.h"
+#include "thread.h"
 
 int do_sema_b_wait_intern (HANDLE sema, int nointerrupt, DWORD timeout);
 
@@ -52,7 +60,7 @@ sem_init (sem_t *sem, int pshared, unsigned int value)
   if (pshared != PTHREAD_PROCESS_PRIVATE)
     return sem_result (EPERM);
 
-  if (!(sv = (sem_t) calloc (1,sizeof (*sv))))
+  if ((sv = (sem_t) calloc (1,sizeof (*sv))) == NULL)
     return sem_result (ENOMEM);
 
   sv->value = value;
@@ -212,8 +220,9 @@ sem_wait (sem_t *sem)
   return sem_result (ret);
 }
 
-int
-sem_timedwait (sem_t *sem, const struct timespec *t)
+/* Internal version which always uses `struct _timespec64`. */
+static int
+__sem_timedwait (sem_t *sem, const struct _timespec64 *t)
 {
   int cur_v, ret = 0;
   DWORD dwr;
@@ -251,10 +260,21 @@ sem_timedwait (sem_t *sem, const struct timespec *t)
   return sem_result (ret);
 }
 
+int sem_timedwait64(sem_t *sem, const struct _timespec64 *t)
+{
+  return __sem_timedwait (sem, t);
+}
+
+int sem_timedwait32(sem_t *sem, const struct _timespec32 *t)
+{
+  struct _timespec64 t64 = {.tv_sec = t->tv_sec, .tv_nsec = t->tv_nsec};
+  return __sem_timedwait (sem, &t64);
+}
+
 int
 sem_post (sem_t *sem)
 {
-  _sem_t *sv;;
+  _sem_t *sv;
 
   if (sem_std_enter (sem, &sv, 0) != 0)
     return -1;
@@ -280,7 +300,7 @@ int
 sem_post_multiple (sem_t *sem, int count)
 {
   int waiters_count;
-  _sem_t *sv;;
+  _sem_t *sv;
 
   if (count <= 0)
     return sem_result (EINVAL);
@@ -350,5 +370,5 @@ sem_getvalue (sem_t *sem, int *sval)
 
   *sval = (int) sv->value;
   pthread_mutex_unlock (&sv->vlock);
-  return 0;  
+  return 0;
 }
