@@ -30,7 +30,7 @@ typedef struct
 #else
 typedef struct _GUID
 {
-#ifndef __LP64__
+#if !defined(__LP64__) && !defined(WINE_UNIX_LIB)
     unsigned long  Data1;
 #else
     unsigned int   Data1;
@@ -56,8 +56,9 @@ typedef struct _GUID
 #ifdef __WINE_UUID_ATTR
 
 extern "C++" {
-    template<typename T> struct __wine_uuidof;
-
+    template<typename T> struct __wine_uuidof {
+        static const GUID uuid;
+    };
     template<typename T> struct __wine_uuidof_type {
         typedef __wine_uuidof<T> inst;
     };
@@ -89,29 +90,19 @@ extern "C++" {
 
 #undef DEFINE_GUID
 
-#ifndef DECLSPEC_HIDDEN
-# if defined(__GNUC__) && !defined(__MINGW32__) && !defined(__CYGWIN__)
-#  define DECLSPEC_HIDDEN __attribute__((visibility ("hidden")))
-# else
-#  define DECLSPEC_HIDDEN
-# endif
-#endif
-
 #ifdef INITGUID
 #ifdef __cplusplus
 #define DEFINE_GUID(name, l, w1, w2, b1, b2, b3, b4, b5, b6, b7, b8) \
-        EXTERN_C const GUID name DECLSPEC_HIDDEN; \
         EXTERN_C const GUID name = \
 	{ l, w1, w2, { b1, b2,  b3,  b4,  b5,  b6,  b7,  b8 } }
 #else
 #define DEFINE_GUID(name, l, w1, w2, b1, b2, b3, b4, b5, b6, b7, b8) \
-        const GUID name DECLSPEC_HIDDEN; \
         const GUID name = \
 	{ l, w1, w2, { b1, b2,  b3,  b4,  b5,  b6,  b7,  b8 } }
 #endif
 #else
 #define DEFINE_GUID(name, l, w1, w2, b1, b2, b3, b4, b5, b6, b7, b8) \
-    EXTERN_C const GUID name DECLSPEC_HIDDEN
+    EXTERN_C const GUID name
 #endif
 
 #define DEFINE_OLEGUID(name, l, w1, w2) \
@@ -167,10 +158,10 @@ typedef GUID FMTID,*LPFMTID;
 #define IsEqualGUID(rguid1, rguid2) (!memcmp(&(rguid1), &(rguid2), sizeof(GUID)))
 inline int InlineIsEqualGUID(REFGUID rguid1, REFGUID rguid2)
 {
-   return (((unsigned int *)&rguid1)[0] == ((unsigned int *)&rguid2)[0] &&
-           ((unsigned int *)&rguid1)[1] == ((unsigned int *)&rguid2)[1] &&
-           ((unsigned int *)&rguid1)[2] == ((unsigned int *)&rguid2)[2] &&
-           ((unsigned int *)&rguid1)[3] == ((unsigned int *)&rguid2)[3]);
+   return (((const unsigned int *)&rguid1)[0] == ((const unsigned int *)&rguid2)[0] &&
+           ((const unsigned int *)&rguid1)[1] == ((const unsigned int *)&rguid2)[1] &&
+           ((const unsigned int *)&rguid1)[2] == ((const unsigned int *)&rguid2)[2] &&
+           ((const unsigned int *)&rguid1)[3] == ((const unsigned int *)&rguid2)[3]);
 }
 #else
 #define IsEqualGUID(rguid1, rguid2) (!memcmp(rguid1, rguid2, sizeof(GUID)))
