@@ -22,6 +22,7 @@
 #define __WIDL_WIDLTYPES_H
 
 #include <stdarg.h>
+#include <stdbool.h>
 #include <assert.h>
 #include "ndrtypes.h"
 #include "wine/list.h"
@@ -92,10 +93,12 @@ enum attr_type
     ATTR_CUSTOM,
     ATTR_DECODE,
     ATTR_DEFAULT,
+    ATTR_DEFAULT_OVERLOAD,
     ATTR_DEFAULTBIND,
     ATTR_DEFAULTCOLLELEM,
     ATTR_DEFAULTVALUE,
     ATTR_DEFAULTVTABLE,
+    ATTR_DEPRECATED,
     ATTR_DISABLECONSISTENCYCHECK,
     ATTR_DISPINTERFACE,
     ATTR_DISPLAYBIND,
@@ -188,7 +191,6 @@ enum expr_type
 {
     EXPR_VOID,
     EXPR_NUM,
-    EXPR_HEXNUM,
     EXPR_DOUBLE,
     EXPR_IDENTIFIER,
     EXPR_NEG,
@@ -346,11 +348,19 @@ struct _attr_t {
   struct location where;
 };
 
+struct integer
+{
+    int value;
+    int is_unsigned;
+    int is_long;
+    int is_hex;
+};
+
 struct _expr_t {
   enum expr_type type;
   const expr_t *ref;
   union {
-    int lval;
+    struct integer integer;
     double dval;
     const char *sval;
     const expr_t *ext;
@@ -520,6 +530,7 @@ struct _type_t {
   struct location where;
   unsigned int ignore : 1;
   unsigned int defined : 1;
+  unsigned int defined_in_import : 1;
   unsigned int written : 1;
   unsigned int user_types_registered : 1;
   unsigned int tfswrite : 1;   /* if the type needs to be written to the TFS */
@@ -539,7 +550,8 @@ struct _var_t {
 
   struct location where;
 
-  unsigned int declonly : 1;
+  /* Should we define the UDT in this var, when writing a header? */
+  unsigned int is_defined : 1;
 
   /* parser-internal */
   struct list entry;
@@ -620,7 +632,9 @@ struct _statement_t {
         typelib_t *lib;
         typeref_list_t *type_list;
     } u;
-    unsigned int declonly : 1; /* for STMT_TYPE and STMT_TYPEDEF */
+    /* For STMT_TYPE and STMT_TYPEDEF, should we define the UDT in this
+     * statement, when writing a header? */
+    unsigned int is_defined : 1;
 };
 
 struct _warning_t {
