@@ -85,7 +85,7 @@ struct sltg_hrefmap
     int *href;
 };
 
-#include "pshpack1.h"
+#pragma pack(push,1)
 struct sltg_typeinfo_header
 {
     short magic;
@@ -221,7 +221,7 @@ struct sltg_impl_info
     short pos;
 };
 
-#include "poppack.h"
+#pragma pack(pop)
 
 static void add_structure_typeinfo(struct sltg_typelib *typelib, type_t *type);
 static void add_interface_typeinfo(struct sltg_typelib *typelib, type_t *type);
@@ -544,7 +544,7 @@ static void init_typeinfo(struct sltg_typeinfo_header *ti, const type_t *type, s
 
         for (i = 0; i < hrefmap->href_count; i++)
         {
-            sprintf(name, "*\\Rffff*#%x", hrefmap->href[i]);
+            snprintf(name, sizeof(name), "*\\Rffff*#%x", hrefmap->href[i]);
             hrefinfo_size += 8 + 2 + strlen(name);
         }
 
@@ -581,7 +581,7 @@ static void write_hrefmap(struct sltg_data *data, const struct sltg_hrefmap *hre
     {
         short len;
 
-        sprintf(name, "*\\Rffff*#%x", hrefmap->href[i]);
+        snprintf(name, sizeof(name), "*\\Rffff*#%x", hrefmap->href[i]);
         len = strlen(name);
 
         append_data(data, &len, sizeof(len));
@@ -1060,7 +1060,7 @@ static int get_func_flags(const var_t *func, int *dispid, int *invokekind, int *
             flags |= 0x10; /* FUNCFLAG_FDISPLAYBIND */
             break;
         case ATTR_HELPCONTEXT:
-            *helpcontext = expr->u.lval;
+            *helpcontext = expr->u.integer.value;
             break;
         case ATTR_HELPSTRING:
             *helpstring = attr->u.pval;
@@ -1155,7 +1155,7 @@ static int add_func_desc(struct sltg_typelib *typelib, struct sltg_data *data, v
                          int idx, int dispid, short base_offset, struct sltg_hrefmap *hrefmap)
 {
     struct sltg_data ret_data, *arg_data;
-    int arg_count = 0, arg_data_size, optional = 0, defaults = 0, old_size;
+    int arg_count = 0, arg_data_size, optional = 0, old_size;
     int funcflags = 0, invokekind = 1 /* INVOKE_FUNC */, helpcontext;
     const char *helpstring;
     const var_t *arg;
@@ -1218,9 +1218,7 @@ static int add_func_desc(struct sltg_typelib *typelib, struct sltg_data *data, v
 
             LIST_FOR_EACH_ENTRY(attr, arg->attrs, const attr_t, entry)
             {
-                if (attr->type == ATTR_DEFAULTVALUE)
-                    defaults++;
-                else if(attr->type == ATTR_OPTIONAL)
+                if (attr->type == ATTR_OPTIONAL)
                     optional++;
             }
         }
@@ -1735,7 +1733,7 @@ static void save_all_changes(struct sltg_typelib *typelib)
 
         expr_t *expr = get_attrp(typelib->typelib->attrs, ATTR_ID);
         if (expr)
-            sprintf(typelib_id, "#%d", expr->cval);
+            snprintf(typelib_id, sizeof(typelib_id), "#%d", expr->cval);
         add_output_to_resources("TYPELIB", typelib_id);
         if (strendswith(typelib_name, "_t.res"))  /* add typelib registration */
             output_typelib_regscript(typelib->typelib);
